==> nextcloud-15.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Update notifications" : "アップデート通知",
    "Channel updated" : "チャンネルを更新しました",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update for %1$s to version %2$s is available." : "%1$s に対するバージョン %2$s へアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "View in store" : "ストア内で表示",
    "Apps with available updates" : "アップデート可能なアプリ",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "What's new?" : "新着情報？",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel:" : "アップデートチャンネル:",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "新しいリリースの後、公開されるまでには時間がかかります。\n新しいバージョンを公開して配布しますが、問題が発見されたときにバージョンをスキップすることがあります。",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "Only notification for app updates are available." : "アプリ更新情報があるときのみ通知する。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています",
    "Checking apps for compatible updates" : "互換性のあるアップデートの有無を確認する",
    "<strong>All</strong> apps have an update for this version available" : "<strong>すべての</strong> アプリにこのバージョンのアップデートがあります",
    "View changelog" : "変更履歴を確認する",
    "Beta" : "ベータ",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> アプリにこのバージョンのアップデートがありません"],
    "Could not start updater, please try the manual update" : "アップデータを起動できませんでした。手動アップデートをお試しください",
    "A new version is available: %s" : "新しいバージョンが利用可能: %s",
    "Checked on %s" : "%s に確認",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "開発版の新しいバージョンにアップデートできます。ただし、アップデート後は安定版にダウングレードできません。"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/ja.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} が利用可能です。アップデート方法について詳細情報を確認してください。",
    "Update notifications" : "アップデート通知",
    "Channel updated" : "チャンネルを更新しました",
    "The update server could not be reached since %d days to check for new updates." : "%d日以降、新しい更新をチェックする更新サーバーにアクセスできませんでした。",
    "Please check the Nextcloud and server log files for errors." : "Nextcloudとサーバーログファイルでエラーがないか確認してください。",
    "Update to %1$s is available." : "%1$s への更新が利用可能です。",
    "Update for %1$s to version %2$s is available." : "%1$s に対するバージョン %2$s へアップデートが利用可能です。",
    "Update for {app} to version %s is available." : " {app} に対するバージョン %s へアップデートが利用可能です。",
    "Update notification" : "アップデート通知",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Nextcloudの更新通知を表示し、アップデータのSSOを提供します。",
    "View in store" : "ストア内で表示",
    "Apps with available updates" : "アップデート可能なアプリ",
    "Open updater" : "アップデーターを開く",
    "Download now" : "今すぐダウンロード",
    "What's new?" : "新着情報？",
    "The update check is not yet finished. Please refresh the page." : "アップデートチェックが完了していません。ページを更新してください。",
    "Your version is up to date." : "最新版です。",
    "A non-default update server is in use to be checked for updates:" : "更新のチェックにデフォルト以外の更新サーバーが利用されています:",
    "Update channel:" : "アップデートチャンネル:",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "新しいリリースの後、公開されるまでには時間がかかります。\n新しいバージョンを公開して配布しますが、問題が発見されたときにバージョンをスキップすることがあります。",
    "Notify members of the following groups about available updates:" : "次のグループのメンバーに利用可能なアップデートを通知する:",
    "Only notification for app updates are available." : "アプリ更新情報があるときのみ通知する。",
    "The selected update channel makes dedicated notifications for the server obsolete." : "選択した更新チャネルでは、廃止サーバーについて専用の通知を行います。",
    "The selected update channel does not support updates of the server." : "選択したチャンネルでは、サーバーのアップデートをサポートしていません。",
    "A new version is available: <strong>{newVersionString}</strong>" : "新しいバージョンが利用可能です: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "{lastCheckedDate} にチェックが入っています",
    "Checking apps for compatible updates" : "互換性のあるアップデートの有無を確認する",
    "<strong>All</strong> apps have an update for this version available" : "<strong>すべての</strong> アプリにこのバージョンのアップデートがあります",
    "View changelog" : "変更履歴を確認する",
    "Beta" : "ベータ",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong> アプリにこのバージョンのアップデートがありません"],
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "開発版の新しいバージョンにアップデートできます。ただし、アップデート後は安定版にダウングレードできません。",
    "Could not start updater, please try the manual update" : "アップデータを起動できませんでした。手動アップデートをお試しください"
},
"nplurals=1; plural=0;");
